==> markdown-react-code-preview-loader-1.0.0.tgz: package/src/utils/index.ts <==
/*
 * @Description: markdown 转化
 */
import { MarkDownTreeType, CodeBlockItemType } from './interface';
import { getTransformValue } from './transform';
import webpack from 'webpack';
export * from './interface';
import remark from 'remark';

/** 转换 代码*/
const getProcessor = (scope: string) => {
  const child = remark.parse(scope) as MarkDownTreeType;
  return child.children;
};

const getMeta = (meta: string | null): Record<string, string | boolean> => {
  let metaData: Record<string, string | boolean> = {};
  if (meta) {
    const [metaItem] = /mdx:(.[\w|:]+)/i.exec(meta) || [];
    const [_, field, val] = (metaItem || '').split(':').map((item) => item.trim());
    metaData[field] = val || true;
  }
  return metaData;
};

/** 获取需要渲染的代码块 **/
const getCodeBlock = (child: MarkDownTreeType['children'], lang: string[] = ['jsx', 'tsx']) => {
  // 获取渲染部分
  const codeBlock: Record<string | number, CodeBlockItemType> = {};
  child.forEach((item) => {
    if (item && item.type === 'code' && lang.includes(item.lang)) {
      const line = item.position.start.line;
      const metaData = getMeta(item.meta);
      if (metaData.preview) {
        let name = typeof metaData.preview === 'string' ? metaData.preview : line;
        const funName = `BaseCode${line}`;
        const returnCode = getTransformValue(item.value, `${funName}.${lang}`, funName);
        codeBlock[line] = {
          code: returnCode,
          name,
          language: item.lang,
          value: item.value,
        };
      }
    }
  });
  return codeBlock;
};

const createStr = (codeBlock: Record<string | number, CodeBlockItemType>) => {
  let baseCodeStr = ``;
  let baseCodeObjStr = ``;
  let codeBlockValue = ``;
  let languageStr = ``;
  Object.entries(codeBlock).forEach(([key, item]) => {
    const { code, value, language, name } = item;
    baseCodeStr += `${code};\n`;
    baseCodeObjStr += `${name}:BaseCode${key},\n`;
    codeBlockValue += `${name}:\`${value}\`,\n`;
    languageStr += `${name}:\`${language}\`,\n`;
  });
  let indexStr = `${baseCodeStr} const languages={${languageStr}};\n const codeBlock={${codeBlockValue}};\n const components={${baseCodeObjStr}}`;
  return indexStr;
};

export const getCodeBlockString = (scope: string, lang: string[] = ['jsx', 'tsx']) => {
  const children = getProcessor(scope);
  const codeBlock = getCodeBlock(children, lang);
  const result = createStr(codeBlock);
  return result;
};

/**
 * 配置好markdown的loader
 * @param {webpack.Configuration} config webpack配置
 * @param {string[]} lang 解析语言
 * @returns {webpack.Configuration}
 * **/
export const mdCodeModulesLoader = (config: webpack.Configuration, lang?: string[]): webpack.Configuration => {
  config.module.rules.forEach((ruleItem) => {
    if (typeof ruleItem === 'object') {
      if (ruleItem.oneOf) {
        ruleItem.oneOf.unshift({
          test: /.md$/,
          use: [
            {
              loader: 'markdown-react-code-preview-loader',
              options: { lang },
            },
          ],
        });
      }
    }
  });
  return config;
};

==> markdown-react-code-preview-loader-1.0.1.tgz: package/src/utils/index.ts <==
/*
 * @Description: markdown 转化
 */
import { MarkDownTreeType, CodeBlockItemType } from './interface';
import { getTransformValue } from './transform';
import webpack from 'webpack';
export * from './interface';
import remark from 'remark';

/** 转换 代码*/
const getProcessor = (scope: string) => {
  const child = remark.parse(scope) as MarkDownTreeType;
  return child.children;
};

const getMeta = (meta: string | null): Record<string, string | boolean> => {
  let metaData: Record<string, string | boolean> = {};
  if (meta) {
    const [metaItem] = /mdx:(.[\w|:]+)/i.exec(meta) || [];
    const [_, field, val] = (metaItem || '').split(':').map((item) => item.trim());
    metaData[field] = val || true;
  }
  return metaData;
};

/** 获取需要渲染的代码块 **/
const getCodeBlock = (child: MarkDownTreeType['children'], lang: string[] = ['jsx', 'tsx']) => {
  // 获取渲染部分
  const codeBlock: Record<string | number, CodeBlockItemType> = {};
  child.forEach((item) => {
    if (item && item.type === 'code' && lang.includes(item.lang)) {
      const line = item.position.start.line;
      const metaData = getMeta(item.meta);
      if (metaData.preview) {
        let name = typeof metaData.preview === 'string' ? metaData.preview : line;
        const funName = `BaseCode${line}`;
        const returnCode = getTransformValue(item.value, `${funName}.${lang}`, funName);
        codeBlock[line] = {
          code: returnCode,
          name,
          language: item.lang,
          value: item.value,
        };
      }
    }
  });
  return codeBlock;
};

const createStr = (codeBlock: Record<string | number, CodeBlockItemType>) => {
  let baseCodeStr = ``;
  let baseCodeObjStr = ``;
  let codeBlockValue = ``;
  let languageStr = ``;
  Object.entries(codeBlock).forEach(([key, item]) => {
    const { code, value, language, name } = item;
    baseCodeStr += `${code};\n`;
    baseCodeObjStr += `${name}:BaseCode${key},\n`;
    codeBlockValue += `${name}:${JSON.stringify(value)},\n`;
    languageStr += `${name}:\`${language}\`,\n`;
  });
  let indexStr = `${baseCodeStr} const languages={${languageStr}};\n const codeBlock={${codeBlockValue}};\n const components={${baseCodeObjStr}}`;
  return indexStr;
};

export const getCodeBlockString = (scope: string, lang: string[] = ['jsx', 'tsx']) => {
  const children = getProcessor(scope);
  const codeBlock = getCodeBlock(children, lang);
  const result = createStr(codeBlock);
  return result;
};

/**
 * 配置好markdown的loader
 * @param {webpack.Configuration} config webpack配置
 * @param {string[]} lang 解析语言
 * @returns {webpack.Configuration}
 * **/
export const mdCodeModulesLoader = (config: webpack.Configuration, lang?: string[]): webpack.Configuration => {
  config.module.rules.forEach((ruleItem) => {
    if (typeof ruleItem === 'object') {
      if (ruleItem.oneOf) {
        ruleItem.oneOf.unshift({
          test: /.md$/,
          use: [
            {
              loader: 'markdown-react-code-preview-loader',
              options: { lang },
            },
          ],
        });
      }
    }
  });
  return config;
};
